@@ -57,7 +57,7 @@ typedef struct {
 
 typedef struct {
     const char *device;
-    int kernel24;
+    int grabDevice;         /* grab the event device? */
     int screen;
     int min_x, min_y, max_x, max_y;
     int abs_x, abs_y, old_x, old_y;
